@@ -1,6 +1,8 @@
 package org.ovirt.vdsm.jsonrpc.client.reactors.stomp;
 
 import static org.ovirt.vdsm.jsonrpc.client.reactors.stomp.impl.Message.HEADER_DESTINATION;
+import static org.ovirt.vdsm.jsonrpc.client.reactors.stomp.impl.Message.HEADER_HEART_BEAT;
+import static org.ovirt.vdsm.jsonrpc.client.reactors.stomp.impl.Message.HEADER_HOST;
 import static org.ovirt.vdsm.jsonrpc.client.utils.JsonUtils.logException;
 
 import java.io.IOException;
@@ -12,9 +14,8 @@ import java.nio.channels.SocketChannel;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLException;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.ovirt.vdsm.jsonrpc.client.ClientConnectionException;
+import org.ovirt.vdsm.jsonrpc.client.internal.ClientPolicy;
 import org.ovirt.vdsm.jsonrpc.client.reactors.Reactor;
 import org.ovirt.vdsm.jsonrpc.client.reactors.SSLEngineNioHelper;
 import org.ovirt.vdsm.jsonrpc.client.reactors.stomp.impl.CommandExecutor;
@@ -22,9 +23,11 @@ import org.ovirt.vdsm.jsonrpc.client.reactors.stomp.impl.Message;
 import org.ovirt.vdsm.jsonrpc.client.reactors.stomp.impl.Message.Command;
 import org.ovirt.vdsm.jsonrpc.client.reactors.stomp.impl.Sender;
 import org.ovirt.vdsm.jsonrpc.client.utils.OneTimeCallback;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public class SSLStompListener extends SSLStompClient implements Sender {
-    private static Log log = LogFactory.getLog(SSLStompListener.class);
+    private static Logger log = LoggerFactory.getLogger(SSLStompListener.class);
     private CommandFactory commandFactory;
 
     public SSLStompListener(Reactor reactor, Selector selector, String hostname, int port,
@@ -40,15 +43,26 @@ public class SSLStompListener extends SSLStompClient implements Sender {
     @Override
     public void sendMessage(byte[] message) {
         send(new Message().message()
-                .withHeader(HEADER_DESTINATION, RESPONSE_QUEUE)
+                .withHeader(HEADER_DESTINATION, DEFAULT_RESPONSE_QUEUE)
                 .withContent(message)
                 .build());
     }
 
+    @Override
+    public void setClientPolicy(ClientPolicy policy) {
+        this.policy = policy;
+    }
+
     void processMessage(Message message) {
         String command = message.getCommand();
         CommandExecutor executor = this.commandFactory.getCommandExecutor(command);
         Message response = executor.execute(message);
+        if (Command.CONNECT.toString().equals(command)) {
+            updatePolicyWithHeartbeat(response.getHeaders().get(HEADER_HEART_BEAT), false);
+            if (message.getHeaders().get(HEADER_HOST) != null) {
+                policy.setIdentifier(message.getHeaders().get(HEADER_HOST));
+            }
+        }
         if (response != null) {
             this.send(response.build());
         }
